@@ -1,3 +1,5 @@
 from .integration import enable_auth
 
-__all__ = ["enable_auth"]
\ No newline at end of file
+__all__ = [
+    "enable_auth",
+]
\ No newline at end of file
